
.. _amrclaw_examples_burgers_2d_square:

Two-dimensional Burgers' equation
===========================================

Two-dimensional Burgers' equation 

    :math:`q_t + 0.5(q^2)_x + 0.5(q^2)_y = 0`

with piecewise constant initial data and periodic boundary conditions.

